@@ -1,5 +1,5 @@
 package Games::LMSolve::Tilt::Base;
-$Games::LMSolve::Tilt::Base::VERSION = '0.12.0';
+$Games::LMSolve::Tilt::Base::VERSION = '0.14.0';
 use strict;
 use warnings;
 
@@ -7,17 +7,16 @@ use vars qw(@ISA);
 
 use Games::LMSolve::Base;
 
-@ISA=qw(Games::LMSolve::Base);
+@ISA = qw(Games::LMSolve::Base);
 
 # x - the x step
 # y - the y step
 # w - which wall
-my %moves_specs =
-(
-    'u' => { 'x' => 0, 'y' => -1, 'w' => 'h'},
-    'd' => { 'x' => 0, 'y' => 1, 'w' => 'h'},
-    'l' => { 'x' => -1, 'y' => 0, 'w' => 'v'},
-    'r' => { 'x' => 1, 'y' => 0, 'w' => 'v'},
+my %moves_specs = (
+    'u' => { 'x' => 0,  'y' => -1, 'w' => 'h' },
+    'd' => { 'x' => 0,  'y' => 1,  'w' => 'h' },
+    'l' => { 'x' => -1, 'y' => 0,  'w' => 'v' },
+    'r' => { 'x' => 1,  'y' => 0,  'w' => 'v' },
 );
 
 # This function moves the ball to the end.
@@ -27,33 +26,37 @@ sub move_ball_to_end
     my $self = shift;
 
     my $coords = shift;
-    my $move = shift;
+    my $move   = shift;
 
-    my ($x,$y) = @$coords;
+    my ( $x, $y ) = @$coords;
     my @intermediate_coords = ();
 
-    if (!exists($moves_specs{$move}))
+    if ( !exists( $moves_specs{$move} ) )
     {
         die "Unknown move \"$move\"!";
     }
 
     my $horiz_walls = $self->{'horiz_walls'};
-    my $vert_walls = $self->{'vert_walls'};
+    my $vert_walls  = $self->{'vert_walls'};
 
-    my ($x_dir, $y_dir, $which_wall) = @{$moves_specs{$move}}{'x','y','w'};
+    my ( $x_dir, $y_dir, $which_wall ) =
+        @{ $moves_specs{$move} }{ 'x', 'y', 'w' };
 
-    push @intermediate_coords, [$x, $y];
-    while (! (($which_wall eq 'v') ?
-        ($vert_walls->[$y]->[$x+(($x_dir<0)?0:1)]) :
-        ($horiz_walls->[$y + (($y_dir<0)?0:1)]->[$x])
-        ))
+    push @intermediate_coords, [ $x, $y ];
+    while (
+        !(
+              ( $which_wall eq 'v' )
+            ? ( $vert_walls->[$y]->[ $x + ( ( $x_dir < 0 ) ? 0 : 1 ) ] )
+            : ( $horiz_walls->[ $y + ( ( $y_dir < 0 ) ? 0 : 1 ) ]->[$x] )
+        )
+        )
     {
         $x += $x_dir;
         $y += $y_dir;
-        push @intermediate_coords, [$x, $y];
+        push @intermediate_coords, [ $x, $y ];
     }
 
-    return ([$x,$y], \@intermediate_coords);
+    return ( [ $x, $y ], \@intermediate_coords );
 }
 
 1;
@@ -68,16 +71,12 @@ Games::LMSolve::Tilt::Base - base class for the tilt mazes' drivers.
 
 =head1 VERSION
 
-version 0.12.0
+version 0.14.0
 
 =head1 SYNOPSIS
 
 NA - should not be used directly.
 
-=head1 VERSION
-
-version 0.12.0
-
 =head1 METHODS
 
 =head2 $self->move_ball_to_end()
